pilot.coordination.nocoord_adaptor.NoCoordinationAdaptor

Package pilot :: Package coordination :: Module nocoord_adaptor :: Class NoCoordinationAdaptor |

# Class NoCoordinationAdaptor

source code

Dummy Adaptor - No distributed coordination done

Class Methods
get_base_url(cls, application_id) | source code
add_pds(cls, application_url, pds) | source code
delete_pds(cls, pds_url) | source code
add_pd(cls, pds_url, pd) | source code
update_pd(cls, pd) | source code
get_pd(cls, pds_url) | source code
list_pd(cls, pds_url) return a list of urls to pd managed by the PDS | source code
delete_pd(cls, pds_url) | source code
add_cds(cls, application_url, cds) | source code
update_cds(cls, cds_url, cds) | source code
delete_cds(cls, cds_url) | source code
add_du(cls, dus_url, du) | source code
get_du(cls, du_url) | source code
update_du(cls, du) | source code
list_du(cls, dus_url) return a list of urls to du managed by the PDS | source code
delete_du(cls, du_url) | source code
get_pds_url(cls, application_url, pds_id) | source code
get_cds_url(cls, application_url, cds_id) | source code

Class Variables
| BASE_URL = ``'``nocoord://localhost/``'``
| BASE_URL_QUERY_STRING = ``'``?dbtype=sqlite3``'``
| PILOT_PATH = ``'``pilot``'``
| PILOT_DATA_PATH = ``'``pilot``'``
| PILOT_DATA_SERVICE_PATH = ``'``pilot/pds``'``
| DATA_UNIT_SERVICE_PATH = ``'``pilot/dus``'``
| COMPUTE_DATA_SERVICE_PATH = ``'``pilot/cds``'``